@@ -88,7 +88,7 @@ clustIndex <- function( y, x, index="all" )
         n <- sum(clsize)
         k <- length(clsize)
         allmean <- apply(x,2,mean)
-        dmean <- sweep(x,2,allmean,"-")
+        dmean <- sweep(x,2,allmean,`-`)
         allmeandist <- sum(dmean^2)
         wgss <- sum(withins)
         bgss <- allmeandist - wgss
@@ -107,7 +107,7 @@ clustIndex <- function( y, x, index="all" )
         varwgss<-rep(0,nvar)
         for (l in 1:nvar)
           varallmean[l] <- mean(x[,l])
-        vardmean <- sweep(x,2,varallmean,"-")
+        vardmean <- sweep(x,2,varallmean,`-`)
         for (l in 1:nvar)
           {
             varallmeandist[l] <- sum((vardmean[,l])^2)
@@ -168,7 +168,7 @@ clustIndex <- function( y, x, index="all" )
     db <- function(withins, centers, cluster)
       {
         mse <- withins/table(cluster)
-        r <- outer(mse, mse, "+") / as.matrix(dist(centers, diag=TRUE))
+        r <- outer(mse, mse, `+`) / as.matrix(dist(centers, diag=TRUE))
         diag(r) <- 0
         db <- mean(apply(r,1,max))
         return(db)
